@@ -151,7 +151,7 @@ class TestGeneralUsage:
                 pass
         """)
         p = testdir.makepyfile("def test_hello(): pass")
-        result = testdir.runpytest(p, "--collectonly")
+        result = testdir.runpytest(p, "--collect-only")
         result.stdout.fnmatch_lines([
             "*MyFile*test_issue88*",
             "*Module*test_issue88*",
@@ -391,15 +391,15 @@ class TestInvocationVariants:
     def test_equivalence_pytest_pytest(self):
         assert pytest.main == py.test.cmdline.main
 
-    def test_invoke_with_string(self, testdir, capsys):
-        retcode = testdir.pytestmain("-h")
+    def test_invoke_with_string(self, capsys):
+        retcode = pytest.main("-h")
         assert not retcode
         out, err = capsys.readouterr()
         assert "--help" in out
         pytest.raises(ValueError, lambda: pytest.main(0))
 
-    def test_invoke_with_path(self, testdir, capsys):
-        retcode = testdir.pytestmain(testdir.tmpdir)
+    def test_invoke_with_path(self, tmpdir, capsys):
+        retcode = pytest.main(tmpdir)
         assert not retcode
         out, err = capsys.readouterr()
 
@@ -408,7 +408,7 @@ class TestInvocationVariants:
             def pytest_addoption(self, parser):
                 parser.addoption("--myopt")
 
-        testdir.pytestmain(["-h"], plugins=[MyPlugin()])
+        pytest.main(["-h"], plugins=[MyPlugin()])
         out, err = capsys.readouterr()
         assert "--myopt" in out
 
@@ -504,7 +504,7 @@ class TestInvocationVariants:
 class TestDurations:
     source = """
         import time
-        frag = 0.02
+        frag = 0.002
         def test_something():
             pass
         def test_2():
@@ -519,7 +519,7 @@ class TestDurations:
         testdir.makepyfile(self.source)
         result = testdir.runpytest("--durations=10")
         assert result.ret == 0
-        result.stdout.fnmatch_lines([
+        result.stdout.fnmatch_lines_random([
             "*durations*",
             "*call*test_3*",
             "*call*test_2*",
@@ -530,12 +530,8 @@ class TestDurations:
         testdir.makepyfile(self.source)
         result = testdir.runpytest("--durations=2")
         assert result.ret == 0
-        result.stdout.fnmatch_lines([
-            "*durations*",
-            "*call*test_3*",
-            "*call*test_2*",
-        ])
-        assert "test_1" not in result.stdout.str()
+        lines = result.stdout.get_lines_after("*slowest*durations*")
+        assert "4 passed" in lines[2]
 
     def test_calls_showall(self, testdir):
         testdir.makepyfile(self.source)
@@ -573,7 +569,7 @@ class TestDurations:
 class TestDurationWithFixture:
     source = """
         import time
-        frag = 0.01
+        frag = 0.001
         def setup_function(func):
             time.sleep(frag * 3)
         def test_1():
@@ -586,9 +582,9 @@ class TestDurationWithFixture:
         result = testdir.runpytest("--durations=10")
         assert result.ret == 0
 
-        result.stdout.fnmatch_lines([
-            "*durations*",
-            "* setup *test_1*",
-            "* call *test_1*",
-        ])
+        result.stdout.fnmatch_lines_random("""
+            *durations*
+            * setup *test_1*
+            * call *test_1*
+        """)
 
