@@ -329,6 +329,24 @@ class TestFunction:
         reprec = testdir.inline_run()
         reprec.assertoutcome(passed=1)
 
+    def test_parametrize_with_non_hashable_values(self, testdir):
+        """Test parametrization with non-hashable values."""
+        testdir.makepyfile("""
+            archival_mapping = {
+                '1.0': {'tag': '1.0'},
+                '1.2.2a1': {'tag': 'release-1.2.2a1'},
+            }
+
+            import pytest
+            @pytest.mark.parametrize('key value'.split(),
+                                     archival_mapping.items())
+            def test_archival_to_version(key, value):
+                assert key in archival_mapping
+                assert value == archival_mapping[key]
+        """)
+        rec = testdir.inline_run()
+        rec.assertoutcome(passed=2)
+
     def test_function_equality_with_callspec(self, testdir, tmpdir):
         items = testdir.getitems("""
             import pytest
@@ -414,7 +432,7 @@ class TestConftestCustomization:
         """)
         testdir.makepyfile("def test_some(): pass")
         testdir.makepyfile(test_xyz="def test_func(): pass")
-        result = testdir.runpytest("--collectonly")
+        result = testdir.runpytest("--collect-only")
         result.stdout.fnmatch_lines([
             "*<Module*test_pytest*",
             "*<MyModule*xyz*",
@@ -467,7 +485,7 @@ class TestConftestCustomization:
                     return MyFunction(name, collector)
         """)
         testdir.makepyfile("def some(): pass")
-        result = testdir.runpytest("--collectonly")
+        result = testdir.runpytest("--collect-only")
         result.stdout.fnmatch_lines([
             "*MyFunction*some*",
         ])
@@ -648,7 +666,7 @@ def test_customized_python_discovery(testdir):
     """)
     p2 = p.new(basename=p.basename.replace("test", "check"))
     p.move(p2)
-    result = testdir.runpytest("--collectonly", "-s")
+    result = testdir.runpytest("--collect-only", "-s")
     result.stdout.fnmatch_lines([
         "*check_customized*",
         "*check_simple*",
@@ -672,7 +690,7 @@ def test_customized_python_discovery_functions(testdir):
         def _test_underscore():
             pass
     """)
-    result = testdir.runpytest("--collectonly", "-s")
+    result = testdir.runpytest("--collect-only", "-s")
     result.stdout.fnmatch_lines([
         "*_test_underscore*",
     ])
@@ -721,7 +739,7 @@ def test_customize_through_attributes(testdir):
             def test_hello(self):
                 pass
     """)
-    result = testdir.runpytest("--collectonly")
+    result = testdir.runpytest("--collect-only")
     result.stdout.fnmatch_lines([
         "*MyClass*",
         "*MyInstance*",
