@@ -97,7 +97,7 @@ class TestCollectFS:
         for x in tmpdir.visit("test_*.py"):
             x.write("def test_hello(): pass")
 
-        result = testdir.runpytest("--collectonly")
+        result = testdir.runpytest("--collect-only")
         s = result.stdout.str()
         assert "test_notfound" not in s
         assert "test_found" in s
@@ -123,7 +123,7 @@ class TestCollectPluginHookRelay:
             def pytest_collect_file(self, path, parent):
                 wascalled.append(path)
         testdir.makefile(".abc", "xyz")
-        testdir.pytestmain([testdir.tmpdir], plugins=[Plugin()])
+        pytest.main([testdir.tmpdir], plugins=[Plugin()])
         assert len(wascalled) == 1
         assert wascalled[0].ext == '.abc'
 
@@ -134,7 +134,7 @@ class TestCollectPluginHookRelay:
                 wascalled.append(path.basename)
         testdir.mkdir("hello")
         testdir.mkdir("world")
-        testdir.pytestmain(testdir.tmpdir, plugins=[Plugin()])
+        pytest.main(testdir.tmpdir, plugins=[Plugin()])
         assert "hello" in wascalled
         assert "world" in wascalled
 
@@ -252,7 +252,7 @@ class TestCustomConftests:
         """)
         sub = testdir.mkdir("sub")
         p = testdir.makepyfile("def test_x(): pass")
-        result = testdir.runpytest("--collectonly")
+        result = testdir.runpytest("--collect-only")
         result.stdout.fnmatch_lines([
             "*MyModule*",
             "*test_x*"
@@ -282,7 +282,7 @@ class TestCustomConftests:
         p = testdir.makepyfile("def test_x(): pass")
         p.copy(sub1.join(p.basename))
         p.copy(sub2.join(p.basename))
-        result = testdir.runpytest("--collectonly")
+        result = testdir.runpytest("--collect-only")
         result.stdout.fnmatch_lines([
             "*MyModule1*",
             "*MyModule2*",
