@@ -1,4 +1,4 @@
-
+import pytest
 from xml.dom import minidom
 import py, sys, os
 
@@ -37,7 +37,7 @@ class TestPython:
         result, dom = runandparse(testdir)
         assert result.ret
         node = dom.getElementsByTagName("testsuite")[0]
-        assert_attr(node, errors=0, failures=1, skips=3, tests=2)
+        assert_attr(node, name="pytest", errors=0, failures=1, skips=3, tests=2)
 
     def test_timing_function(self, testdir):
         testdir.makepyfile("""
@@ -427,16 +427,16 @@ def test_invalid_xml_escape():
 def test_logxml_path_expansion(tmpdir, monkeypatch):
     from _pytest.junitxml import LogXML
 
-    home_tilde = os.path.normpath(os.path.expanduser('~/test.xml'))
+    home_tilde = py.path.local(os.path.expanduser('~')).join('test.xml')
 
-    xml_tilde = LogXML('~/test.xml', None)
+    xml_tilde = LogXML('~%stest.xml' % tmpdir.sep, None)
     assert xml_tilde.logfile == home_tilde
 
     # this is here for when $HOME is not set correct
     monkeypatch.setenv("HOME", tmpdir)
     home_var = os.path.normpath(os.path.expandvars('$HOME/test.xml'))
 
-    xml_var = LogXML('$HOME/test.xml', None)
+    xml_var = LogXML('$HOME%stest.xml' % tmpdir.sep, None)
     assert xml_var.logfile == home_var
 
 def test_logxml_changingdir(testdir):
@@ -450,3 +450,16 @@ def test_logxml_changingdir(testdir):
     assert result.ret == 0
     assert testdir.tmpdir.join("a/x.xml").check()
 
+def test_escaped_parametrized_names_xml(testdir):
+    testdir.makepyfile("""
+        import pytest
+        @pytest.mark.parametrize('char', ["\\x00"])
+        def test_func(char):
+            assert char
+    """)
+    result, dom = runandparse(testdir)
+    assert result.ret == 0
+    node = dom.getElementsByTagName("testcase")[0]
+    assert_attr(node,
+        name="test_func[#x00]")
+
